@@ -7,7 +7,7 @@ from datetime import datetime
 from functools import wraps
 from multiprocessing.pool import ThreadPool
 from typing import (
-    Any, Iterator, List, Union,
+    Any, Iterator, List, Tuple, Union,
 )
 
 from pyhocon import ConfigFactory, ConfigTree
@@ -212,12 +212,12 @@ class HiveTableLastUpdatedExtractor(Extractor):
         sql_alchemy_extractor.init(sql_alchemy_conf)
         return sql_alchemy_extractor
 
-    def _choose_default_non_partitioned_sql_stm(self) -> str:
+    def _choose_default_non_partitioned_sql_stm(self) -> Tuple(str):
         url = make_url(self._conf.get_string("extractor.sqlalchemy.conn_string"))
         if url.drivername.lower() in ['postgresql', 'postgres']:
-            return self.DEFAULT_POSTGRES_NON_PARTITIONED_TABLE_SQL_STATEMENT, self.DEFAULT_POSTGRES_ADDTIONAL_WHERE_CLAUSE
+            return (self.DEFAULT_POSTGRES_NON_PARTITIONED_TABLE_SQL_STATEMENT, self.DEFAULT_POSTGRES_ADDTIONAL_WHERE_CLAUSE)
         else:
-            return self.DEFAULT_NON_PARTITIONED_TABLE_SQL_STATEMENT, self.DEFAULT_ADDTIONAL_WHERE_CLAUSE
+            return (self.DEFAULT_NON_PARTITIONED_TABLE_SQL_STATEMENT, self.DEFAULT_ADDTIONAL_WHERE_CLAUSE)
 
     def _get_filesystem(self) -> FileSystem:
         fs = FileSystem()
